.. include:: ../references.txt

.. _datasets:

***************************
datasets - Reduced datasets
***************************

.. currentmodule:: gammapy.datasets

Introduction
============

The `gammapy.datasets` sub-package contains classes to handle reduced
gamma-ray data for modeling and fitting.

Getting Started
===============

The `Dataset` class bundles reduced data, IRFs and model to perform
likelihood fitting and joint-likelihood fitting.


Reference/API
=============

.. automodapi:: gammapy.datasets
    :no-inheritance-diagram:
    :include-all-objects:
